#
# dotguess-fishing.R,  3 Jul 22
#
# Data from
# The Dot-Guessing Game: A “Fruit Fly” for Human Computation Research
# John J. Horton

library("colorspace")
library("plyr")
library("lme4")


# Plot rounded estimates in a unique color
col_round=function(rnd_val)
{
rnd_col=rainbow(length(rnd_val))

dum=sapply(1:length(rnd_val), function(X)
				{
				pts=subset(anc, guess == rnd_val[X])
				points(pts$anchor, pts$guess, col=rnd_col[X])
				})
}


# Plot actual/estimate by unique actual color
dot_guess=function(df)
{
points(df$dots, df$guess, col=pal_col[df$url[1]])
}

# Count of the number of times each estimate value is given
dot_distrib=function(df)
{
lines(count(df$guess), col=pal_col[df$url[1]])
}

# Kernel density plot of estimates for each actual dot count
dot_binned=function(df)
{
# bins=hist(log(df$guess), breaks=20, plot=FALSE)
# lines(bins$breaks[-1], bins$counts, col=pal_col[df$url[1]])
bins=density(log(df$guess))
lines(bins, col=pal_col[df$url[1]])
}


par(bty="l")
par(las=1)
par(pch="+") 
pal_col=rainbow(2)


# No boundary around plot of 500 dots
par(mar = c(0, 0, 0, 0))
n = 500
X = c(runif(n, 0, 1), runif(n, 0, 1))
plot(X, pch=15, axes = F, xlab = "", ylab = "")

# Put a bounary back
par(mar = c(4, 4, 0, 0))

# Ignore table 1 of paper
# Number of dots appearing in successive image files.
# This list is from the paper's Rnw source
pic_dots = c(456,854,1243,4000,8200,2543,310)

anc=read.csv("dot_guessing_game/cooked/anchor.csv", as.is=TRUE)
anc=subset(anc, guess < 5e3)

incen=read.csv("dot_guessing_game/cooked/guess.csv", as.is=TRUE)

# Given image file name, map to number of dots present
incen$url=as.numeric(substring(substring(incen$url, 40), 1, 1))
incen$dots=pic_dots[incen$url]

# Remove what look like outlier mistakes
incen=subset(incen, (guess >=50) & (guess <= 5e4))


plot(anc$anchor, anc$guess, log="xy", ylim=c(100, 2000))
lines(c(50, 2000), c(50, 2000), col="red")

# In one case estimate == anchor
anc=subset(anc, relative != "")

# Both models have equal goodness of fit
anc_lmod=glm(log(guess) ~ log(anchor):relative, data=anc, subset=(guess < 2500))
summary(anc_mod)
anc_mod=glm(guess ~ anchor:relative, data=anc, subset=(guess < 2500))
summary(anc_mod)

plot(count(anc$guess), xlim=c(100, 2000), log="x", col="grey")

# Check spikes at round numbers
points(150, 6.2, col="red")
points(250, 13.2, col="red")
points(300, 9.2, col="red")
points(350, 7.2, col="red")
points(400, 6.2, col="red")
points(450, 5.2, col="red")
points(500, 10.2, col="red")
points(550, 4.2, col="red")
points(600, 7.2, col="red")
points(650, 5.2, col="red")
points(700, 7.2, col="red")
points(750, 2.2, col="red")
points(800, 6.2, col="red")
points(900, 2.2, col="red")
points(1000, 5.2, col="red")


plot(anc$anchor, anc$guess, log="xy", col="grey",
	ylim=c(100, 2000),
	xlab="Anchor", ylab="Estimate")
lines(c(50, 2000), c(50, 2000), col="salmon")

# Round number estimates
rnd_num=c(150, 250, 300, 350, 400, 450, 500, 550, 600, 650, 700, 800, 1000)
col_round(rnd_num)

# Fraction of round numbers
nrow(subset(anc, guess %in% rnd_num))/nrow(anc)


g250=subset(anc, guess == 250)
points(g250$anchor, g250$guess, col="blue")


# Experiment B
incen=subset(incen, (accept_time > 0))

pal_col=rainbow(length(pic_dots))
plot( 1, type="n", log="xy",
	xlim=c(200, 1e4), ylim=c(50, 5e4),
	xlab="Actual dots", ylab="Estimate")

dum=ddply(incen, .(dots), dot_guess)

two_col=rainbow(2)
lines(c(200, 1e4), c(200, 1e4), col=two_col[2])
dot_mod=glm(log(guess) ~ log(dots), data=incen)
pred=predict(dot_mod, newdata=data.frame(dots=pic_dots))
lines(pic_dots, exp(pred), col=two_col[1])

plot( 1, type="n", log="x",
	xlim=c(50, 5e4), ylim=c(1, 15),
	xlab="Guess", ylab="Occurrences")

dum=ddply(incen, .(dots), dot_distrib)

# hist(incen$guess)
plot( 1, type="n",
	xlim=c(4, 11), ylim=c(0, 1),
	xlab="Guess", ylab="Occurrences")

dum=ddply(incen, .(dots), dot_binned)


# Various attempts to fit regression models
incen=subset(incen, bonus != "")
incen=subset(incen, gender != "")

inc_mod=glm(accept_time ~ log(guess)+bonus+gender, data=incen)
summary(inc_mod)

# inc_amod=lmer(accept_time ~ log(dots)+bonus*gender+ (bonus | id), data=incen)
inc_amod=lmer(accept_time ~ bonus*gender+ (bonus | id), data=incen)
summary(inc_amod)

inc_rmod=lmer(log(guess) ~ log(dots)+bonus*gender+ (bonus | id), data=incen)
summary(inc_rmod)


# actual/estimated ratio
incen$ea_ratio=incen$guess/incen$dots

plot(sort(incen$ea_ratio), log="y")

s_ratio=ddply(incen, .(id), function(df)
				{
				if (nrow(df) < 3) return(NULL)
				low=length(which(df$ea_ratio < 1))
				high=length(which(df$ea_ratio >= 1))
				return(c(low, high))
				})
s_ratio$is_high=(s_ratio$V2/(s_ratio$V1+s_ratio$V2))
plot(sort(s_ratio$is_high))

nrow(s_ratio)
length(which(s_ratio$is_high == 0))/nrow(s_ratio)  # All low
length(which(s_ratio$is_high == 1))/nrow(s_ratio)  # All high

